/*
  The MIT License (MIT)

  Copyright (c) 2018 J. Eric Townsend

  Permission is hereby granted, free of charge, to any person obtaining a copy
  of this software and associated documentation files (the "Software"), to deal
  in the Software without restriction, including without limitation the rights
  to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
  copies of the Software, and to permit persons to whom the Software is
  furnished to do so, subject to the following conditions:

  The above copyright notice and this permission notice shall be included in
  all copies or substantial portions of the Software.

  THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
  IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
  FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
  AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
  LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
  OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
  THE SOFTWARE.
*/

var serial;
var portName = '/dev/cu.usbmodem1421';
var dataRead; 
var xPos = 0;   

function setup()
{
    serial = new p5.SerialPort(); 
    // now set a number of callback functions for SerialPort
    serial.on('list', printList); 
    serial.on('connected', serverConnected);
    serial.on('open', portOpen); 
    serial.on('data', serialEvent);
    serial.on('error', serialError);
    serial.on('close', portClose); 
    
    serial.list();
    serial.open(portName);

  createCanvas(400, 300);
  background(0x08, 0x16, 0x40);
}

function draw() {
  graphData(dataRead);
  }

//from nyu tutorial https://itp.nyu.edu/physcomp/labs/labs-serial-communication/lab-serial-input-to-the-p5-js-ide/

function graphData(newData) {
  // map the range of the input to the window height:
  var yPos = map(newData, 0, 255, 0, height);
  // draw the line in a pretty color:
  stroke(0xA8, 0xD9, 0xA7);
  line(xPos, height, xPos, height - yPos);
  // at the edge of the screen, go back to the beginning:
  if (xPos >= width) {
    xPos = 0;
    // clear the screen by resetting the background:
    background(0x08, 0x16, 0x40);
  } else {
    // increment the horizontal position for the next reading:
    xPos++;
  }
}



function printList(portList) {
    for (var i = 0; i < portList.length; i++) {
    print(i + " " + portList[i]);
  }
}

function serverConnected()
{
    print('serverConnected');
}

function portOpen()
{
    print('portOpen');
}

function serialEvent()
{

    dataRead = Number(serial.read());
}

function serialError(err)
{
    print('serialError ' + err);
}

function portClose()
{
    print('portClose');
}
